| fao_concordance_path | R Documentation |
Gives a file path to the concordance data excel workbook
fao_concordance_path()
a path to to the concordance data excel workbook bundled with this package
fao_concordance_path()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.