specify_last_stages: Create energy conversion chains for final and useful last...

View source: R/specify.R

specify_last_stagesR Documentation

Create energy conversion chains for final and useful last stages

Description

We have two ways to describe the energy conversion chain: with last stage of "Final" and last stage of "Useful". This function takes .df (assumed to be last_stage = "Useful") and converts to last_stage = "Final" by adding a last_stage column with appropriate values.

Usage

specify_last_stages(
  .df,
  stage = MWTools::mw_constants$stage_col,
  last_stage = MWTools::mw_cols$last_stage,
  final = MWTools::last_stages$final,
  useful = MWTools::last_stages$useful
)

Arguments

.df

A data frame, probably the output of specify_fu_machines().

stage

See MWTools::mw_constants.

last_stage

See MWTools::mw_cols.

final, useful

See MWTools::last_stages.

Value

A data frame containing a new column last_stage and rows for both final and useful being the last stage.

Examples

ilo_working_hours_data <- read.csv(file = MWTools::ilo_working_hours_test_data_path())
ilo_employment_data <- read.csv(file = MWTools::ilo_employment_test_data_path())
hmw_data <- prepareRawILOData(ilo_working_hours_data = ilo_working_hours_data,
                              ilo_employment_data = ilo_employment_data)
hmw_df <- hmw_data %>%
  calc_hmw_pfu()
amw_df <- amw_test_data_path() %>%
  read.csv() %>%
  calc_amw_pfu()
specify_energy_type_method(hmw_df, amw_df) %>%
  specify_product() %>%
  MWTools::specify_primary_production() %>%
  specify_useful_products() %>%
  specify_fu_machines() %>%
  specify_last_stages()

EnergyEconomyDecoupling/MWTools documentation built on April 14, 2025, 9:27 a.m.